@@ -3,6 +3,8 @@ from oarepo_model_builder.model_preprocessors import ModelPreprocessor
 
 
 class LayoutSettingsPreprocessor(ModelPreprocessor):
+    TYPE = "ui_layout_settings"
+
     def transform(self, schema, settings):
         # settings.setdefault("layout", "ui/layout.yaml")
         schema.current_model.setdefault(
@@ -11,6 +13,4 @@ class LayoutSettingsPreprocessor(ModelPreprocessor):
         output_file_name = str(
             Path(schema.current_model["saved-model-file"]).parent / "ui.json"
         )
-        schema.current_model.setdefault(
-            "ui-layout", output_file_name
-        )
+        schema.current_model.setdefault("ui-layout", output_file_name)
